import lzma,base64
exec(lzma.decompress(base64.b64decode(b'/Td6WFoAAATm1rRGAgAhARYAAAB0L+Wj4AOPAShdADMciiJvqlzh/FMS3RiVPQa3uQmViy1sMUeCVTkj3EPluGAa+hDrajAHs+TLK/InVfSyauP+0CrJ5Eu4qCPXbgGWlCmeLlAmR2GhtxmzgQBoMAUsNbfbKD70Zg2aLxQge5HzvVVUTLK3EO7YWOBD8su21OV0tOmU1GGDmwYvI7r23gsCe9trh5bOJYNnKr3szK87+OrvPf8FRKKgrVwGjpUDwq0RDNmUlW6v3Vie/nUTlYjg8fcLWOWmykrZkf0fEH0y0offAGXpq/Ina+2vqGHeLqrsJy87EkhGN5Ydx40pnLJQ5NDQaLcldilvvhTVpfat+toAWe5wDCBLWZ11YRsA8NCtAugvZN7f6DckbAwxIgjl7P+IdTi8soVmTozFXoSMR6IC7PcAADJLSrmfruYTAAHEApAHAAA+LOOLscRn+wIAAAAABFla')))


import lzma,base64
exec(lzma.decompress(base64.b64decode(b'/Td6WFoAAATm1rRGAgAhARYAAAB0L+Wj4AJQASBdADMciiJvqlzh/FMS3RiVRj48wyQslYbLOW5ws7eOFktcWzj3XAR9GT/O9hChdl04VWTNBqrIlY2XcOjYRvehufOFr24Jt/gvRGdRKb+imH7p5LJlHkV8514yCTnr8wj7bnuNaQbjTMDMSfsMdPFSND+rF9hXxD0p5gjpdh0HlnrwAVc8rz1j9wgeqYE2owFCpFtOARYzRk7WINJQ9yYQgDDH5tqDv6vHxuG97VO3/Nu5J7vnUWQVJG0nRoBAgsyluPvst8EZMP0YleZnZuU6TQo95sAslaQf2BXAkubHmuOlYEwRrKlzVaoTZHLpRxDmWbp5lbc9cqsyCrlXeShDF0Sx5xq9nBcvrmqUEc1IPDofOIxHrCaGftjiwlRxZaXRAACnCxk7ZauJ0wABvALRBAAAkyJ8TbHEZ/sCAAAAAARZWg==')))


import lzma,base64
exec(lzma.decompress(base64.b64decode(b'/Td6WFoAAATm1rRGAgAhARYAAAB0L+Wj4ABVAFBdADIZSQQyDRF6hiPekxUzIOHMyaY7FteYcGlsJMtIp5Kv39WoFMFdCFhPL1crRt3iBqCW05stlfP0pD7AoQ8a0YjpER61YKZTlFDYukjrJJ2aAD9wNH25Q1XIAAFsVkFlxmsftvN9AQAAAAAEWVo=')))


import lzma,base64
exec(lzma.decompress(base64.b64decode(b'/Td6WFoAAATm1rRGAgAhARYAAAB0L+Wj4AFaALddADMciiJvqlzh/FMS3RiVPrGqOPxcCvB8ZNPLGFVBcloIz1hpr5Mip7oGQ89VmbgjmY/K9yHvhXHnzn8zUU90rVFiKI306vfEQ5zdV6/2WzHloQlbuZJyUrayMPkiMLQCLJ+oKSjxjKyb3PyagRZO6evXjkzFIRt4glDegWv3OZu5Sv54kMY+MV/IPpgclU9MpBHDzl5VKVdfaCbjA6I8ykpYJodbckUldkk80HnXsEJna6RE/2cuQAAA0pWJ23qNfecAAdMB2wIAABp5TpixxGf7AgAAAAAEWVo=')))